@@ -134,7 +134,7 @@ function capitalize(s) {
 
 function toCodePoint(s) {
     let codePoint = s.charCodeAt(0);
-    if (codePoint > 0xD800) {
+    if (codePoint >= 0xD800 && codePoint <= 0xDBFF) {
         let high = codePoint;
         let low = s.charCodeAt(1);
         codePoint = 0x10000 + (high - 0xD800) * 0x400 + (low - 0xDC00);
